<?php

namespace Drupal\Tests\datetime_flatpickr\Functional;

use Drupal\Tests\datetime\Functional\DateTestBase;

/**
 * Datetime flatpickr form test.
 *
 * @group datetime_flatpickr
 */
class DateTimeFlatPickrWidgetTest extends DateTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'classy';

  /**
   * The default display settings to use for the formatters.
   *
   * @var array
   */
  protected $defaultSettings = ['timezone_override' => ''];

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'node',
    'entity_test',
    'datetime',
    'field_ui',
    'datetime_flatpickr',
  ];

  /**
   * {@inheritdoc}
   */
  protected function getTestFieldType() {
    return 'datetime';
  }

  /**
   * Tests Date Time Flat Pickr functionality.
   */
  public function testDateTimeFlatPickrWidget() {
    $field_name = $this->fieldStorage->getName();
    $field_label = $this->field->label();

    // Ensure field is set to a date only field.
    $this->fieldStorage->setSetting('datetime_type', 'date');
    $this->fieldStorage->save();

    /** @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface $display_repository */
    $display_repository = \Drupal::service('entity_display.repository');

    // Change the widget to a datelist widget.
    $display_repository->getFormDisplay($this->field->getTargetEntityTypeId(), $this->field->getTargetBundle())
      ->setComponent($field_name, [
        'type' => 'datetime_flatpickr',
        'settings' => [
          'date_order' => 'YMD',
          'dateFormat' => 'Y-m-d H:i',
        ],
      ])
      ->save();
    \Drupal::service('entity_field.manager')->clearCachedFieldDefinitions();

    // Display creation form.
    $this->drupalGet('entity_test/add');
    $this->assertSession()->elementTextContains('xpath', '//div[@id="edit-' . $field_name . '-wrapper"]/*/label', $field_label);
    $this->assertSession()->elementExists('xpath', '//input[@flatpickr-name="entity_test-' . $field_name . '"]');
    $this->assertSession()->elementExists('xpath', '//input[@id="edit-' . $field_name . '-0-value"]');
  }

}
